Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Daemon ¶
type Daemon interface {
// Start starts the daemon, returning an error if preconditions for startup
// fail.
Start() error
// Stop stops the daemon, returning an error if one was encountered during
// shutdown.
Stop() error
// Err returns a channel that the caller can use to listen for terminal errors
// indicating a premature shutdown of the Daemon.
Err() <-chan error
// Name returns the name of the daemon
Name() string
}
A Daemon is a managed subprocess comprised of one or more goroutines that can be managed via a consistent, simple interface.
Click to show internal directories.
Click to hide internal directories.