Documentation
¶
Index ¶
- type Entry
- type Report
- type Writer
- func (w Writer) Debug(msg string)
- func (w Writer) Debugf(msg string, a ...interface{})
- func (w Writer) Error(msg string)
- func (w Writer) Errorf(msg string, a ...interface{})
- func (w Writer) Fatal(msg string)
- func (w Writer) Fatalf(msg string, a ...interface{})
- func (w Writer) Info(msg string)
- func (w Writer) Infof(msg string, a ...interface{})
- func (w Writer) Warn(msg string)
- func (w Writer) Warnf(msg string, a ...interface{})
- func (w Writer) WithValue(key string, val interface{}) Writer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Entry ¶
type Entry struct {
Level logrus.Level
Message string
Context map[string]interface{}
Time time.Time
}
Entry ...
type Report ¶
type Report struct {
Out io.Writer
LogLevel logrus.Level
// contains filtered or unexported fields
}
Report reports debug, warning, & errors
func (*Report) HasWarnings ¶
HasWarnings returns true if there are any warnings entries in the report
type Writer ¶
type Writer struct {
// contains filtered or unexported fields
}
Writer exposes methods for adding entries to a report
Click to show internal directories.
Click to hide internal directories.